==> xdtp-1.1.4.tgz: xdtp-1.1.4/java/jp/co/ongs/xdtp/transform/XDTPTransform.java <==
/*
 * $Id: XDTPTransform.java,v 1.2 2005/10/10 17:17:19 ozawa Exp $
 *
 * Copyright (c) 2002- ONGS Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 */

package jp.co.ongs.xdtp.transform;

/**
 * Xml Document Transfer Program
 * 
 * @author Masanori OZAWA (ozawa@ongs.co.jp)
 * @version $Revision: 1.2 $
 */
public class XDTPTransform
{
    static {
        System.loadLibrary("xdtp_java");
    }

    /**
     * Ԥޤ
     *  set/get ϤΥ᥽åɤѤ뤳Ȥ򤱤Ƥ
     * Ѵ set/get ϥ᥽åɤѤ뤳ȤϤǤޤ
     * 
     * @return  true ᤷޤ
     */
    public native boolean initialize();
    
    /**
     * ֥ȤԤޤ
     * Ѵ塢֥ȤѤ뤳Ȥʤ䡢֤ѹ
     * ϡ˸ƤӽФɬפޤ
     */
    public native void uninitialize();
    
    /**
     * Ѵ¹Ԥޤ
     * 
     * @param anInput ѴXMLե
     * @param anOutput եʴ¸ΥեϾ񤭤ޤ
     * @return Ѵ true ᤷޤ
     */
    public native boolean transform(String anInput, String anOutput);
    
    /**
     * Ѵȯ顼åɸ२顼ؽϤޤ
     * 顼ȯʤäϡɽޤ
     * 
     * @param out 
     */
    public native void showErrorMsg();
    
    /**
     * XMLʸϤå򥹥åפޤ
     * 
     * @param bCheck åפ true ꤷޤ
     */
    public native void skipXMLCheck(boolean bCheck);
    
    /**
     * XMLʸϤå򥹥åפ뤫Ĵ٤ޤ
     * 
     * @return åפ true ᤷޤ
     */
    public native boolean isXMLCheck();
    
    /**
     * ѴXSLեɲäޤ
     * 
     * @param aPath XSLեؤΥѥ
     * @param useOutputType ϷݻѤ true ꤷޤ
     */
    public native void addXSLFile(String aPath, boolean useOutputType);
    
    /**
     * ѴXSLեΰ򥯥ꥢޤ
     */
    public native void clearXSLFile();
    
    /**
     * ѴXSLեΰޤ
     * 
     * @return ѴXSLեΰ
     */
    public native String[] getXSLFileList();

    /**
     * ѴXDTP⥸塼ɲäޤ
     * 
     * @param aPath XDTP⥸塼ؤΥѥ
     */
    public native void addXDTPModule(String aPath);

    /**
     * ѴXDTP⥸塼򥯥ꥢޤ
     */
    public native void clearXDTPModule();
    
    /**
     * ѴXDTP⥸塼ΰޤ
     * 
     * @return ѴXDTP⥸塼ΰ
     */
    public native String[] getXDTPModuleList();

    /**
     * ѴXDTP⥸塼ؤΥץɲäޤ
     * 
     * @param anOption ɲåץ
     */
    public native void addOption(String anOption);

    /**
     * ѴXDTP⥸塼ؤΥץ򥯥ꥢޤ
     */
    public native void clearOption();
    
    /**
     * ѴXDTP⥸塼ؤΥץΰޤ
     * 
     * @return ѴXDTP⥸塼ؤΥץΰ
     */
    public native String[] getOptionList();

    /**
     * Ϸꤷޤ
     * 
     * @param aType Ϸ
     */
    public native void setOutputType(String aType);

    /**
     * Ϸޤ
     * 
     * @return Ϸ
     */
    public native String getOutputType();

    /**
     * åɽ٥ꤷޤ
     * 
     * @param aMode åɽ٥
     */
    public native void setVerboseMode(int aMode);
    
    /**
     * åɽ٥ޤ
     */
    public native int getVerboseMode();

    /**
     * ϥեΥ󥳡ɤꤷޤ
     * 
     * @param anEncoding ϥեΥ󥳡
     */
    public native void setInputEncoding(String anEncoding);

    /**
     * ϥեΥ󥳡ɤޤ
     * 
     * @return ϥեΥ󥳡
     */
    public native String getInputEncoding();
    
    /**
     * ϥեΥ󥳡ɤꤷޤ
     * 
     * @param anEncoding ϥեΥ󥳡
     */
    public native void setOutputEncoding(String anEncoding);

    /**
     * ϥեΥ󥳡ɤޤ
     * 
     * @return ϥեΥ󥳡
     */
    public native String getOutputEncoding();

    /**
     * 󥹥ȥ饯
     */
    public XDTPTransform()
    {
        this.native_object = XDTPTransform.createNativeObject();
        
        if (0 == this.native_object) {
            throw new OutOfMemoryError("XDTPTransform: Out of memory error.");
        }
    }

    /**
     * ǥȥ饯
     */
    protected void finalize()
        throws Throwable
    {
        XDTPTransform.destroyNativeObject(this.native_object);
    }

    /**
     * ͥƥ֤XDTPTransform֥Ȥۤޤ
     */
    private native static int createNativeObject();
    
    /**
     * ͥƥ֤XDTPTransform֥Ȥ˴ޤ
     */
    private native static void destroyNativeObject(int aNativeObject);
    
    /**
     * ͥƥ֤XDTPTransform֥
     */
    private int native_object = 0;
}

==> xdtp-1.2.0.tgz: xdtp-1.2.0/java/jp/co/ongs/xdtp/transform/XDTPTransform.java <==
/*
 * $Id: XDTPTransform.java,v 1.3 2006/03/16 01:02:56 ozawa Exp $
 *
 * Copyright (c) 2002- ONGS Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 */

package jp.co.ongs.xdtp.transform;

/**
 * Xml Document Transform Program
 * 
 * @author Masanori OZAWA (ozawa@ongs.co.jp)
 * @version $Revision: 1.3 $
 */
public class XDTPTransform
{
    static {
        System.loadLibrary("xdtp_java");
    }

    /**
     * Ԥޤ
     *  set/get ϤΥ᥽åɤѤ뤳Ȥ򤱤Ƥ
     * Ѵ set/get ϥ᥽åɤѤ뤳ȤϤǤޤ
     * 
     * @return  true ᤷޤ
     */
    public native boolean initialize();
    
    /**
     * ֥ȤԤޤ
     * Ѵ塢֥ȤѤ뤳Ȥʤ䡢֤ѹ
     * ϡ˸ƤӽФɬפޤ
     */
    public native void uninitialize();
    
    /**
     * Ѵ¹Ԥޤ
     * 
     * @param anInput ѴXMLե
     * @param anOutput եʴ¸ΥեϾ񤭤ޤ
     * @return Ѵ true ᤷޤ
     */
    public native boolean transform(String anInput, String anOutput);
    
    /**
     * Ѵȯ顼åɸ२顼ؽϤޤ
     * 顼ȯʤäϡɽޤ
     * 
     * @param out 
     */
    public native void showErrorMsg();
    
    /**
     * XMLʸϤå򥹥åפޤ
     * 
     * @param bCheck åפ true ꤷޤ
     */
    public native void skipXMLCheck(boolean bCheck);
    
    /**
     * XMLʸϤå򥹥åפ뤫Ĵ٤ޤ
     * 
     * @return åפ true ᤷޤ
     */
    public native boolean isXMLCheck();
    
    /**
     * ѴXSLեɲäޤ
     * 
     * @param aPath XSLեؤΥѥ
     * @param useOutputType ϷݻѤ true ꤷޤ
     */
    public native void addXSLFile(String aPath, boolean useOutputType);
    
    /**
     * ѴXSLեΰ򥯥ꥢޤ
     */
    public native void clearXSLFile();
    
    /**
     * ѴXSLեΰޤ
     * 
     * @return ѴXSLեΰ
     */
    public native String[] getXSLFileList();

    /**
     * ѴXDTP⥸塼ɲäޤ
     * 
     * @param aPath XDTP⥸塼ؤΥѥ
     */
    public native void addXDTPModule(String aPath);

    /**
     * ѴXDTP⥸塼򥯥ꥢޤ
     */
    public native void clearXDTPModule();
    
    /**
     * ѴXDTP⥸塼ΰޤ
     * 
     * @return ѴXDTP⥸塼ΰ
     */
    public native String[] getXDTPModuleList();

    /**
     * ѴXDTP⥸塼ؤΥץɲäޤ
     * 
     * @param anOption ɲåץ
     */
    public native void addOption(String anOption);

    /**
     * ѴXDTP⥸塼ؤΥץ򥯥ꥢޤ
     */
    public native void clearOption();
    
    /**
     * ѴXDTP⥸塼ؤΥץΰޤ
     * 
     * @return ѴXDTP⥸塼ؤΥץΰ
     */
    public native String[] getOptionList();

    /**
     * Ϸꤷޤ
     * 
     * @param aType Ϸ
     */
    public native void setOutputType(String aType);

    /**
     * Ϸޤ
     * 
     * @return Ϸ
     */
    public native String getOutputType();

    /**
     * åɽ٥ꤷޤ
     * 
     * @param aMode åɽ٥
     */
    public native void setVerboseMode(int aMode);
    
    /**
     * åɽ٥ޤ
     */
    public native int getVerboseMode();

    /**
     * ϥեΥ󥳡ɤꤷޤ
     * 
     * @param anEncoding ϥեΥ󥳡
     */
    public native void setInputEncoding(String anEncoding);

    /**
     * ϥեΥ󥳡ɤޤ
     * 
     * @return ϥեΥ󥳡
     */
    public native String getInputEncoding();
    
    /**
     * ϥեΥ󥳡ɤꤷޤ
     * 
     * @param anEncoding ϥեΥ󥳡
     */
    public native void setOutputEncoding(String anEncoding);

    /**
     * ϥեΥ󥳡ɤޤ
     * 
     * @return ϥեΥ󥳡
     */
    public native String getOutputEncoding();

    /**
     * 󥹥ȥ饯
     */
    public XDTPTransform()
    {
        this.native_object = XDTPTransform.createNativeObject();
        
        if (0 == this.native_object) {
            throw new OutOfMemoryError("XDTPTransform: Out of memory error.");
        }
    }

    /**
     * ǥȥ饯
     */
    protected void finalize()
        throws Throwable
    {
        XDTPTransform.destroyNativeObject(this.native_object);
    }

    /**
     * ͥƥ֤XDTPTransform֥Ȥۤޤ
     */
    private native static int createNativeObject();
    
    /**
     * ͥƥ֤XDTPTransform֥Ȥ˴ޤ
     */
    private native static void destroyNativeObject(int aNativeObject);
    
    /**
     * ͥƥ֤XDTPTransform֥
     */
    private int native_object = 0;
}
